==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Revision:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 is gebaseerd op QCAD, een vrije (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Dit betekent dat iedereen kan &lt;a href=&apos;%1&apos;&gt;meedoen&lt;/a&gt;!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Delen van deze software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>De software wordt verspreid in de hoop dat deze nuttig is maar ZONDER ENIGE GARANTIE, zelfs zonder impliciete garantie van VERKOOPBAARHEID of GESCHIKTHEID VOOR EEN BEPAALD DOEL.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Geen informatie beschikbaar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Versie:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licentie:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Aanmaakdatum:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Architectuur:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Compiler:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 is een programma voor computerondersteund tekenen (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 is gratis (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins en script add-ons zijn beschikbaar onder hun respectieve licentie (zie tabblad &apos;Plugins&apos;).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Alle merk- en productnamen zijn handelsmerken of geregistreerde handelsmerken van hun respectievelijke eigenaren.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Delen van deze software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Delen van deze software © 2012 Nokia Corporation en / of haar dochterondernemingen (of organen).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Geen plugins gevonden.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Actief</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inactief (herstart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Probeerversie:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Bestand:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Fout:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Script add-ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Geen script add-ons gevonden.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Meewerkende</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Over ...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmering</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Sjablonen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icons</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testen, beoordelingen en kleine correcties</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Credits</source>
        <translation>Meewerkende</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>About</name>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Revision:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 is gebaseerd op QCAD, een vrije (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Dit betekent dat iedereen kan &lt;a href=&apos;%1&apos;&gt;meedoen&lt;/a&gt;!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Delen van deze software © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>De software wordt verspreid in de hoop dat deze nuttig is maar ZONDER ENIGE GARANTIE, zelfs zonder impliciete garantie van VERKOOPBAARHEID of GESCHIKTHEID VOOR EEN BEPAALD DOEL.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Geen informatie beschikbaar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Beschrijving:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qt Versie:</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Delen van deze software © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Licentie:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Aanmaakdatum:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Architectuur:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Compiler:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License Key:</source>
        <translation>Licentienummer:</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 is een programma voor computerondersteund tekenen (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 is gratis (open source) software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins en script add-ons zijn beschikbaar onder hun respectieve licentie (zie tabblad &apos;Plugins&apos;).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Alle merk- en productnamen zijn handelsmerken of geregistreerde handelsmerken van hun respectievelijke eigenaren.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Delen van deze software © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Delen van deze software © 2012 Nokia Corporation en / of haar dochterondernemingen (of organen).</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="obsolete">Delen van deze software © 2008-2017 The Qt Company Ltd. {2008-2018 ?}</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Delen van deze software © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>No plugins found.</source>
        <translation>Geen plugins gevonden.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Actief</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inactief (herstart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Probeerversie:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Bestand:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Fout:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Script add-ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Geen script add-ons gevonden.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Meewerkende</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>&amp;Over ...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmering</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Sjablonen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Icons</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testen, beoordelingen en kleine correcties</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Credits</source>
        <translation>Meewerkende</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
</context>
</TS>
